<?php
/**
 * Null compression and decompression class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009, 2010 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class NullCompressor extends BaseFrameworkSystem implements Compressor {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor!
		parent::__construct(__CLASS__);
	}

	/**
	 * Create a new compressor channel based a given compression handler
	 *
	 * @return	$cInstance	An instance of this class
	 */
	public final static function createNullCompressor () {
		// Get new instance
		$cInstance = new NullCompressor();

		// Return the compressor instance
		return $cInstance;
	}

	/**
	 * Null compression stream
	 *
	 * @param	$streamData		Mixed non-object stream data
	 * @return	$streamData		The compressed stream data	
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	public function compressStream ($streamData) {
		if (is_object($streamData)) {
			// Throw an exception
			throw new InvalidObjectException($streamData, self::EXCEPTION_UNEXPECTED_OBJECT);
		}

		// Return the compressed stream
		return $streamData;
	}

	/**
	 * Null decompression stream
	 *
	 * @param	$streamData		Mixed non-object stream data
	 * @return	$streamData		The decompressed stream data	
	 * @throws	InvalidObjectException	If the stream is an object
	 */
	public function decompressStream ($streamData) {
		if (is_object($streamData)) {
			// Throw an exception
			throw new InvalidObjectException($streamData, self::EXCEPTION_UNEXPECTED_OBJECT);
		}

		// Return the decompressed stream
		return $streamData;
	}

	/**
	 * Getter for the file extension of this compressor
	 *
	 * @return	$string		Returns always "null"
	 */
	public final function getCompressorExtension () {
		return "null";
	}
}

// [EOF]
?>
