<?php
/**
 * A general Registry
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009, 2010 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class BaseRegistry extends BaseFrameworkSystem implements Registerable {
	/**
	 * Instance of this class
	 */
	private static $registryInstance = null;

	/**
	 * Instance registry
	 */
	private $instanceRegistry = array();

	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Checks wether an instance key was found
	 *
	 * @param	$instanceKey	The key holding an instance in registry
	 * @return	$exists			Wether the key exists in registry
	 */
	public function instanceExists ($instanceKey) {
		// Does this key exists?
		$exists = (isset($this->instanceRegistry[$instanceKey]));

		// Return the result
		return $exists;
	}

	/**
	 * Adds/overwrites a new instance to the registry at the given key
	 *
	 * @param	$instanceKey		The key to identify the instance
	 * @param	$objectInstance		An instance we shall store
	 * @return	void
	 */
	public function addInstance ($instanceKey, Registerable $objectInstance) {
		$this->instanceRegistry[$instanceKey] = $objectInstance;
	}

	/**
	 * Gets a registered instance or null if not found
	 *
	 * @param	$instanceKey		The key to identify the instance
	 * @return	$objectInstance		An instance we shall store
	 * @throws	NullPointerException	If the requested key is not found
	 */
	public function getInstance ($instanceKey) {
		// By default the instance is not in registry
		$objectInstance = null;

		// Is the instance there?
		if ($this->instanceExists($instanceKey)) {
			$objectInstance = $this->instanceRegistry[$instanceKey];
		} // END - if

		// Still not fetched?
		if (is_null($objectInstance)) {
			// This might happen if a non-registered key was requested
			throw new NullPointerException($this, self::EXCEPTION_IS_NULL_POINTER);
		} // END - if

		// Return the result
		return $objectInstance;
	}
}

// [EOF]
?>
